(function() {
  var bridge = {
    install: function(Vue) {
      Vue.prototype.$bridge = this;
    },
    callback: null,
    ua: {
      isApp: /dlapp/i.test(navigator.userAgent),
      isWeixin: /MicroMessenger/i.test(navigator.userAgent),
      isIos: /iphone|ipad/i.test(navigator.userAgent),
      isAndroid: /android/i.test(navigator.userAgent),
      isMobile: /iphone|ipad|android|mobile/i.test(navigator.userAgent),
      isUC: /UCWEB|UCBrowser/i.test(navigator.userAgent)
    },
    /**
     * app区域传输内容至Web
     * @param {数据项} params
     * params: {action: '', data: ''} action: 执行动作， data:关键字数据
     */
    invokeWeb: function(params){
          switch(params.action){
            case 'auxiliary':
              //TODO 查询调用智库数据接口
    		  operate.intelligentContent(params.data);
              break;
          }
          return true;
    },
    /**
	     * 页面跳转
	     * @options  {String}  页面跳转配置参数
	     * @action  {String}    操作
	     * @data {String}   数据
	     */
    go: function(options) {
        if (navigator.userAgent.match(/(iPhone|iPod|iPad);?/i)) {
            window.webkit.messageHandlers.sendMessage.postMessage({action:options.action, data:encodeURIComponent(options.data)});
        }else if(navigator.userAgent.match(/android/i)){
            let jsonstr = JSON.stringify({action:options.action, data:encodeURIComponent(options.data)});
            window.android.postMessage(jsonstr);
        }
    },
    /**
     * 设置用户信息
     * @param {用户数据json字符串} user 
     */
    authority: function(user) {
      window.localStorage.setItem('userInfo', user); 
      return user;
    },
    /**
     * 获取用户信息
     */
    getUserInfo: function(){
      var user = window.localStorage.getItem('userInfo');
      return JSON.parse(user);
    },
    /**
     * 关闭web区域
     */
    finish: function() {
      this.go({action: 'finish', data:''});
      alert("closed");
    },
    /**
     * 打开页面
     * @param {页面标签} page 
     */
    open: function(page) {
      this.go({action: 'open', data:page});
    },
    /**
     * 打电话
     * @param {电话} mobile 
     */
    tel: function(mobile) {
      this.go({action: 'call', data:mobile});
    },
    /**
     * 传输数据
     * @param {数据} content 
     */
    postData: function(content) {  
      this.go({action: 'post', data: content});
    },
    /**
     * 退出登录
     * @param {数据} userData 
     */
    loginOut: function(content) {  
      this.go({action: 'loginOut', data: content});
    },
    /**
     * 登录后把用户登录信息传递给左侧ipad端
     * @param {数据} userData 
     */
    postUserData: function(content) {  
      this.go({action: 'login', data: content});
    },
    /**
     * 分享
     */
    share : function(id,type){
    	this.go({action: 'post', data: content});
    },
    /**
     * 获取app左侧录音权限
     */
    getVoice: function(){
    	this.go({action: 'voiceDataInfo', data: 'bounds'});
    },
    /**
     * 页面回退
     */
    goBack: function() {      
      this.go({action: 'back', data: ''});
    },
    /**
     * 回首页
     */
    goHome: function() {      
      this.go({action: 'goHome', data: ''});
    },
    /**
    * 一键成文
    */
    writeBack: function(count) {
      this.go({action: 'writeBack', data: count});
    },
    /**
    * 看新句
    */
    findNewBack: function(count) {
      this.go({action: 'findNewBack', data: count});
    },
    /**
    * 智能核校
    */
    intellectCheckBack: function(count) {
      this.go({action: 'intellectCheckBack', data: count});
    },
    backEvtBind: function() {
      if (window.mobile) {
        console.log("手机浏览器，不需要绑定回退键。");
        return;
      }
      document.onkeydown = function(evt) {
        if (evt && evt.keyCode == 8) {
          let inputsFocus = document.querySelectorAll("input:focus, textarea:focus");
          if (inputsFocus && inputsFocus.length) {
            console.log("正在输入。。。");
            return;
          }
          bridge.backEvt();
        }
      }
    },
    backEvt() {
      let thisVue = window.vueComponent;
      let currentComp;
      if (thisVue && thisVue.$children && thisVue.$children[0]) {
        currentComp = thisVue.$children[0].$children[0];
      }
      if (!currentComp) {
        console.warn("没有找到vue实例，请检查代码。。。。");
        return;
      }
      let pops = document.querySelectorAll("div.vux-popup-show");
      if (pops && pops.length) { //popup
        for (let i = 0; i < pops.length; i++) {
          // bridge.findVueCompByDom(pops[i]);
          bridge.trggerBackEvt(currentComp, "popup", "2");
        }
      } else { //DHeard
        bridge.trggerBackEvt(currentComp, "d-header", "1");
      }
    },
    /**
     * 触发组件的Dheader并且返回 广度遍历
     * @param  {VueComponent} vue     [VueComponent]
     * @param  {String} tagName 			[Vue实例]
     * @param  {String} type    			[1 d-header | 2 popup]
     * @return {[type]}         [description]
     */
    trggerBackEvt: function(vue, tagName, type) {
      let arr = [];
      arr.push(vue);
      while (arr.length) {
        let comp = arr.shift(); //获取数组第一个元素 并且出队
        if (tagName == comp.$options._componentTag) { //找到对应组件
          if ("1" == type) {
            if (comp.leftOptions && comp.leftOptions.back) { //有back函数
              comp.goBack();
            } else { //触发点击事件
              comp.$nextTick(function(){
                comp.$el.querySelector(".left-arrow").click();
              });
              // setTimeout(function(){
              //   comp.$el.querySelector(".left-arrow").click();
              // },10);
            }
            return null;
          } else if ("2" == type) {
            comp.show = false;
          }
        } else if (comp.$children && comp.$children.length) { //把子组件推入数组
          for (let i = 0; i < comp.$children.length; i++) {
            arr.push(comp.$children[i]);
          }
        }
      }
    }
  };

  if (typeof exports == "object") {
    module.exports = bridge;
  } else if (typeof define == "function" && define.amd) {
    define([], function() {
      return bridge;
    })
  } else if (window.Vue) {
    window.bridge = bridge;
    Vue.use(bridge);
  }
  window.bridge = bridge;
  window.bridge.backEvtBind();
})();
